package
Version:
v0.0.0-...-471d7c0
Opens a new window with list of versions in this module.
Published: Sep 21, 2016
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 12
Opens a new window with list of known importers.
Documentation
¶
type Message struct {
From string `json:"from,omitempty"`
To string `json:"to"`
Time time.Time `json:"time"`
Message string `json:"message"`
}
Message is a chat message.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.